#ifndef NT2_INCLUDE_CONSTANTS_ONEO_7_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_ONEO_7_HPP_INCLUDED

#include <nt2/constant/include/constants/oneo_7.hpp>

#endif
